% EXPANDLIST Expands a list of points by replacing the NaNs with vectors
% USAGE
%   z=expandlist(v,vals)
% INPUTS
%   v    : kxd matrix, each row is a point
%   vals : d-dimensional cell array of column vectors
% OUTPUTS
%   z    : nxd matrix of sorted points
% Any value of v equal to NaN is replaced by the associated vector in vals
%
% Example:
%   v=[1 NaN 3;NaN NaN 1;1 NaN 1]; vals={[1;2;3],[0;1],[0;1;2]};  z=expandlist(v,vals)
% returns
%  z =
%     1     0     1
%     1     0     3
%     1     1     1
%     1     1     3
%     2     0     1
%     2     1     1
%     3     0     1
%     3     1     1
% Note that only unique points are returned. Thus the function returns the
% same points when called using 
%   v=[1 NaN 3;NaN NaN 1]; vals={[1;2;3],[0;1],[0;1;2]};  z=expandlist(v,vals)
function z=expandlist(v,vals)
  [n,d]=size(v);
  n1=length(vals{1});
  z=[];
  for k=1:n
    zk=[];
    for j=1:d
      if isnan(v(k,j)),   zk=gridmake(zk,vals{j});
      else,               zk(:,j)=v(k,j);
      end
    end
    z=[z;zk];
  end  
  z=unique(z,'rows');