% NEAREST Finds the nearest points in one series to those in another
% USAGE
%   [z,ind]=nearest(x,y,p);
% INPUTS
%   x : nxd matrix
%   y : mxd matrix
%   p : positive scalar [optional], order of norm
% OUTPUTS
%  z   : mxd matrix
%  ind : mx1 vector of integers
%
% z(i,:) is the point in x nearest (in the p-norm) to y(i,:)
% ind(i) is the row value of that point in x (i.e., z=x(ind,:))
%
% The norm use is the p-norm d(x,y)=(sum(abs(x-y).^p).^(1/p)
% The default is p=1
function [z,ind]=nearest(x,y,p);
if nargin<3 | isempty(p), p=1; end
[n,d]=size(y);
z=zeros(n,d);
ind=zeros(n,1);

u=ones(size(x,1),1);
for i=1:n
  yi=y(i,:);
  [scratch,ind(i)]=min(sum(abs(x-yi(u,:)).^p,2));
  z(i,:)=x(ind(i),:);
end